/* StarPU --- Runtime system for heterogeneous multicore architectures.
 *
 * Copyright (C) 2010-2025  University of Bordeaux, CNRS (LaBRI UMR 5800), Inria
 *
 * StarPU is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or (at
 * your option) any later version.
 *
 * StarPU is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See the GNU Lesser General Public License in COPYING.LGPL for more details.
 */

#ifndef __PROGRESS_HOOK_H__
#define __PROGRESS_HOOK_H__

#pragma GCC visibility push(hidden)

/** @file */

void _starpu_init_progression_hooks(void);

unsigned _starpu_execute_registered_progression_hooks(void);

#pragma GCC visibility pop

#endif /* !__PROGRESS_HOOK_H__ */
